@@ -50,7 +50,7 @@ sub import {
     };
 
     my $newline = sub {
-        return ${$properties{_linebreak}} . (' ' x $properties{_current_indent});
+        return $properties{_linebreak} . (' ' x $properties{_current_indent});
     };
 
     my $indent = sub {
@@ -65,11 +65,15 @@ sub import {
         return;
     };
 
-    my $imported = sub (\[@$%&];%) {
+    my $imported_p = sub (\[@$%&];%) {
         my ($item, $p) = @_;
         return Data::Printer::p( $item, %properties );
     };
 
+    my $imported_np = sub (\[@$%&];%) {
+        my ($item, $p) = @_;
+        return Data::Printer::np( $item, %properties );
+    };
     {
         no strict 'refs';
         *{"$caller\::filter"}  = $filter;
@@ -77,7 +81,8 @@ sub import {
         *{"$caller\::outdent"} = $outdent;
         *{"$caller\::newline"} = $newline;
 
-        *{"$caller\::p"} = $imported;
+        *{"$caller\::np"} = $imported_np;
+        *{"$caller\::p"} = $imported_p;
 
         *{"$caller\::_filter_list"}   = $filters;
         *{"$caller\::_extra_options"} = $extras;
@@ -106,7 +111,7 @@ Create your filter module:
   filter 'SCALAR', sub {
       my ($ref, $properties) = @_;
       my $val = $$ref;
-      
+
       if ($val > 100) {
           return 'too big!!';
       }
@@ -362,5 +367,3 @@ Copyright 2011 Breno G. de Oliveira C<< <garu at cpan.org> >>. All rights reserv
 
 This module is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>.
-
-
